==> tslm-1.1.0.2-Server-img.tar.gz: opt/IBM/ermm/lib/cli/Ermm/CLI/LsDrive.pm <==
#!/usr/bin/perl -w
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2012 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.3 - 12/01/24 01:48:37
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#
#-----------------------------------------------------------------------

package Ermm::CLI::LsDrive;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "lsdrive [-l | -s | -x | -v | -access | -lib <name> | -group <name> | -pcl <pcl> |  -hdr [on|off] | -help, -? | -match <c> | -order <c> | -number <c> | -fmt [xml|stanza|delim=c]] [<drivename>]";

#
# list drives
#
sub lsdrive {
    my ($i, $longOutput, $shortOutput, $ermmOutput, $result);
    my ($response, $access, $match, $order, $number, $library, $group, $pcl);
    my $help = 0;
    my $matchString = "";
    my $orderString = "";
    my $numberString = "";
    my $reportmode = "";
    my $reportString = "";
    my $flag = "";

    #
    # get defaults from configuration
    #
    my $format = $Ermm::CLI::Conf::format;
    my $delimiter = $Ermm::CLI::Conf::delimiter;
    my $header = $Ermm::CLI::Conf::header;

    #
    # the classname for xml output
    #
    my $className = "Drive";

    #
    # attributes listed by default
    #
    my $defaultReport =
        " Drive.\"DriveName\" Drive.\"LibraryName\" Drive.\"DMName\"".
        " Drive.\"CartridgePCL\" Drive.\"DriveGroupName\"".
        " Drive.\"DriveOnline\" Drive.\"DriveDisabled\"".
        " Drive.\"DriveBroken\"";

    #
    # attributes listed if -l option given
    #
    my $longReport = $defaultReport .
        " Drive.\"DriveStateSoft\" Drive.\"DriveStateHard\"".
        " Drive.\"DrivePriority\" Drive.\"DriveNumberMounts\"".
        " Drive.\"DriveTimeMountedLast\" Drive.\"DriveTimeMountedTotal\"".
        " Drive.\"Manufacturer\" Drive.\"Model\" Drive.\"SerialNumber\"";

    #
    # attributes listed if -s option given
    #
    my $shortReport = "Drive.\"DriveName\"";

    #
    # attribute names on headline
    #
    my @propNames = ("Name", "Library", "DM",
                     "PCL", "DriveGroup",
                     "Online", "Disabled", "Broken",
                     "StateSoft", "StateHard", "Priority",
                     "Mounts", "MountedLast", "TimeMountedTotal",
                     "Manufacturer", "Model", "SerialNumber");
    #
    # attribute types
    #
    my @typeNames = ("string", "string", "string",
                     "string", "string",
                     "string", "string", "string",
                     "string", "string", "int",
                     "int", "dateTime", "string",
                     "string", "string", "string");

    #
    # process command line options
    #
    $result = GetOptions ("l"        => \$longOutput, # flag
                          "s"        => \$shortOutput,# flag
                          "x"        => \$ermmOutput, # flag
                          "v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "access"   => \$access, # flag
                          "fmt=s"    => \$format, # string
                          "help|?"   => \$help,   # flag
                          "hdr=s"    => \$header, # string
                          "lib=s"    => \$library, # string
                          "group=s"  => \$group, # string
                          "pcl=s"    => \$pcl, # string
                          "match=s"  => \$match, # string
                          "order=s"  => \$order, # string
                          "number=s" => \$number); # string

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_LSDRIVE', $synopsis);
        exit 1;
    }

    #
    # check header option
    #
    if ($header eq "on" || $header eq "yes") {
        $header = 1;
    }

    #
    # get delimiter from -fmt option
    #
    if ($format =~ /^delim=(.*)/) {
        $format = "delim";
        $delimiter = $1;
    }

    #
    # add drive names to match clause
    #
    foreach $i (1 .. $#ARGV) {
        $matchString .= "streq(Drive.\"DriveName\" \"$ARGV[$i]\")";
    }

    if ($#ARGV > 0) {
        $matchString = "or($matchString)";
    }

    #
    # add match clause if specified
    #
    if ($match) {
        $matchString = "and($matchString $match)";
    }

    #
    # add DriveGroupName restriction if specified
    #
    if ($access) {
        $matchString = "and($matchString strne(Drive.\"DriveGroupName\" \"NoAccess\"))";
    }

    #
    # add library restriction if specified
    #
    if ($library) {
        $matchString = "and($matchString streq(Drive.\"LibraryName\" ".
            "\"$library\"))";
    }

    #
    # add drivegroup restriction if specified
    #
    if ($group) {
        $matchString = "and($matchString streq(Drive.\"DriveGroupName\" ".
            "\"$group\"))";
    }

    #
    # add pcl restriction if specified
    #
    if ($pcl) {
        $matchString = "and($matchString streq(Drive.\"CartridgePCL\" ".
            "\"$pcl\"))";
    }

    if ($order) {
        $orderString = "$order";
    }
    else {
        $orderString = "strlohi(Drive.\"DriveName\")";
    }

    if ($number) {
        $numberString = "$number";
        $flag = "q";
    }

    #
    # build report string
    #
    if ($longOutput) {
        $reportString .= $longReport;
    }
    elsif ($shortOutput) {
        $reportString .= $shortReport;
    }
    elsif ($ermmOutput) {
        $reportString .= "$className";
        $reportmode = "namevalue";
    }
    else {
        $reportString .= $defaultReport;
    }

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # if number is not specified, print total number of objects.
    #
    if (!$flag) {
      my $sendString = Ermm::CLI::Main::composeMMPShow($Ermm::CLI::Conf::taskId,
                                                       $matchString,
                                                       $orderString,
                                                       $numberString,
                                                       $reportString,
                                                       "number");

      Ermm::CLI::Main::send($sendString);
      $response = Ermm::CLI::Main::getResponse();

      #
      # get total number of objects.
      #
      @values = Ermm::CLI::Main::getKeyValueResults($response);

      if ( ($#values < 0) || ($values[0][0] < 1) ) {
          Ermm::CLI::Main::printtext('EMM7009I');
          exit;
      }
    }
    my $records = $values[0][0];
    my $recread = 0;

    #
    # send command to server
    #
    Ermm::CLI::Main::sendMMPShow($Ermm::CLI::Conf::taskId,
                                 $matchString,
                                 $orderString,
                                 $numberString,
                                 $reportString,
                                 $reportmode);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

    #
    # Begin loop
    #
    do {
        if ($ermmOutput) {
          #
          # -x option specified; print raw TSLM output
          #
          print $response,"\n";
        }
        else {
          #
          # start normal output processing
          #
          @values = Ermm::CLI::Main::getKeyValueResults($response);

          if ($#values < 0) {
              exit;
          }
          Ermm::CLI::Main::printResults($format, $delimiter, $header, $className,
                                      \@propNames, \@typeNames, \@values);
        }
        $recread += $Ermm::CLI::Conf::objlimit;
        if ($recread >= $records) {
            $flag = "q";
        }

        #
        # Get next part of response
        #
        if (!$flag) {
          Ermm::CLI::Main::nextMMPShowPart();
          #
          # receive response from server
          #
          $response = Ermm::CLI::Main::getResponse();

          #
          # Check if response has values
          #
            if ($response =~ m/text\s*\[.+\]/) {
              if ($Ermm::CLI::Conf::mode) {
                $flag = " ";
              }
              else {
                $flag = "";
              }
            }
            else {
              $flag = "q";
            }

          #
          # Prompt continue or quit
          #
            while ($flag ne "" && $flag ne "q") {
              Ermm::CLI::Main::printtext('CLIMSG_PROMT');
              $flag = <STDIN>;
              chomp $flag;
            }
        }

    }  while (!$flag)
}


1;

==> tslm-1.2.0.1-Server-img.tar.gz: opt/IBM/ermm/lib/cli/Ermm/CLI/LsDrive.pm <==
#!/usr/bin/perl -w
#-----------------------------------------------------------------------
# Licensed Materials - Property of IBM
#
# IBM Tape System Library Manager
#
# (C) Copyright IBM Corp. 2004, 2013 All Rights Reserved
#-----------------------------------------------------------------------
#
# @version 1.4 - 13/02/25 01:07:15
#
# @brief
#
# Change activities:
#     - 2004-03-16: Initial version
#     - 2013-02-25: added -enabled, -disabled
#
#-----------------------------------------------------------------------

package Ermm::CLI::LsDrive;
use Getopt::Long;
use Term::ReadLine;
use Ermm::CLI::Conf;
use Ermm::CLI::Main;

$synopsis = "lsdrive [-l | -s | -x | -v | -access | -lib <name> | -group <name> | -pcl <pcl> |  -enabled | -disabled |  -hdr [on|off] | -help, -? | -match <c> | -order <c> | -number <c> | -fmt [xml|stanza|delim=c]] [<drivename>]";

#
# list drives
#
sub lsdrive {
    my ($i, $longOutput, $shortOutput, $ermmOutput, $result);
    my ($response, $access, $match, $order, $number, $library, $group, $pcl);
    my $help = 0;
    my $matchString = "";
    my $orderString = "";
    my $numberString = "";
    my $reportmode = "";
    my $reportString = "";
    my $flag = "";

    #
    # get defaults from configuration
    #
    my $format = $Ermm::CLI::Conf::format;
    my $delimiter = $Ermm::CLI::Conf::delimiter;
    my $header = $Ermm::CLI::Conf::header;

    #
    # the classname for xml output
    #
    my $className = "Drive";

    #
    # attributes listed by default
    #
    my $defaultReport =
        " Drive.\"DriveName\" Drive.\"LibraryName\" Drive.\"DMName\"".
        " Drive.\"CartridgePCL\" Drive.\"DriveGroupName\"".
        " Drive.\"DriveOnline\" Drive.\"DriveDisabled\"".
        " Drive.\"DriveBroken\"";

    #
    # attributes listed if -l option given
    #
    my $longReport = $defaultReport .
        " Drive.\"DriveStateSoft\" Drive.\"DriveStateHard\"".
        " Drive.\"DrivePriority\" Drive.\"DriveNumberMounts\"".
        " Drive.\"DriveTimeMountedLast\" Drive.\"DriveTimeMountedTotal\"".
        " Drive.\"Manufacturer\" Drive.\"Model\" Drive.\"SerialNumber\"";

    #
    # attributes listed if -s option given
    #
    my $shortReport = "Drive.\"DriveName\"";

    #
    # attribute names on headline
    #
    my @propNames = ("Name", "Library", "DM",
                     "PCL", "DriveGroup",
                     "Online", "Disabled", "Broken",
                     "StateSoft", "StateHard", "Priority",
                     "Mounts", "MountedLast", "TimeMountedTotal",
                     "Manufacturer", "Model", "SerialNumber");
    #
    # attribute types
    #
    my @typeNames = ("string", "string", "string",
                     "string", "string",
                     "string", "string", "string",
                     "string", "string", "int",
                     "int", "dateTime", "string",
                     "string", "string", "string");

    #
    # process command line options
    #
    $result = GetOptions ("l"        => \$longOutput, # flag
                          "s"        => \$shortOutput,# flag
                          "x"        => \$ermmOutput, # flag
                          "v"        => \$Ermm::CLI::Conf::verbose, # flag
                          "access"   => \$access, # flag
                          "enabled"  => \$enabled, # flag
                          "disabled" => \$disabled, # flag
                          "fmt=s"    => \$format, # string
                          "help|?"   => \$help,   # flag
                          "hdr=s"    => \$header, # string
                          "lib=s"    => \$library, # string
                          "group=s"  => \$group, # string
                          "pcl=s"    => \$pcl, # string
                          "match=s"  => \$match, # string
                          "order=s"  => \$order, # string
                          "number=s" => \$number); # string

    #
    # check if we should print usage infos
    #
    if ($result != 1 || $help == 1) {
        Ermm::CLI::Main::printtext('_USAGE_LSDRIVE', $synopsis);
        exit 1;
    }

    #
    # check header option
    #
    if ($header eq "on" || $header eq "yes") {
        $header = 1;
    }

    #
    # get delimiter from -fmt option
    #
    if ($format =~ /^delim=(.*)/) {
        $format = "delim";
        $delimiter = $1;
    }

    #
    # add drive names to match clause
    #
    foreach $i (1 .. $#ARGV) {
        $matchString .= "streq(Drive.\"DriveName\" \"$ARGV[$i]\")";
    }

    if ($#ARGV > 0) {
        $matchString = "or($matchString)";
    }

    #
    # add match clause if specified
    #
    if ($match) {
        $matchString = "and($matchString $match)";
    }

    #
    # add DriveGroupName restriction if specified
    #
    if ($access) {
        $matchString = "and($matchString strne(Drive.\"DriveGroupName\" \"NoAccess\"))";
    }

    #
    # add DriveDisabled == true restriction if specified
    #
    if ($disabled && !$enabled) {
        $matchString = "and($matchString streq(Drive.\"DriveDisabled\" \"true\"))";
    }

    #
    # add DriveDisabled == true restriction if specified
    #
    if (!$disabled && $enabled) {
        $matchString = "$matchString and(streq(Drive.\"DriveDisabled\" \"false\"))";
    }

    #
    # add library restriction if specified
    #
    if ($library) {
        $matchString = "and($matchString streq(Drive.\"LibraryName\" ".
            "\"$library\"))";
    }

    #
    # add drivegroup restriction if specified
    #
    if ($group) {
        $matchString = "and($matchString streq(Drive.\"DriveGroupName\" ".
            "\"$group\"))";
    }

    #
    # add pcl restriction if specified
    #
    if ($pcl) {
        $matchString = "and($matchString streq(Drive.\"CartridgePCL\" ".
            "\"$pcl\"))";
    }

    if ($order) {
        $orderString = "$order";
    }
    else {
        $orderString = "strlohi(Drive.\"DriveName\")";
    }

    if ($number) {
        $numberString = "$number";
        $flag = "q";
    }

    #
    # build report string
    #
    if ($longOutput) {
        $reportString .= $longReport;
    }
    elsif ($shortOutput) {
        $reportString .= $shortReport;
    }
    elsif ($ermmOutput) {
        $reportString .= "$className";
        $reportmode = "namevalue";
    }
    else {
        $reportString .= $defaultReport;
    }

    #
    # connect to TSLM server
    #
    Ermm::CLI::Main::connect();

    #
    # if number is not specified, print total number of objects.
    #
    if (!$flag) {
      my $sendString = Ermm::CLI::Main::composeMMPShow($Ermm::CLI::Conf::taskId,
                                                       $matchString,
                                                       $orderString,
                                                       $numberString,
                                                       $reportString,
                                                       "number");

      Ermm::CLI::Main::send($sendString);
      $response = Ermm::CLI::Main::getResponse();

      #
      # get total number of objects.
      #
      @values = Ermm::CLI::Main::getKeyValueResults($response);

      if ( ($#values < 0) || ($values[0][0] < 1) ) {
          Ermm::CLI::Main::printtext('EMM7009I');
          exit;
      }
    }
    my $records = $values[0][0];
    my $recread = 0;

    #
    # send command to server
    #
    Ermm::CLI::Main::sendMMPShow($Ermm::CLI::Conf::taskId,
                                 $matchString,
                                 $orderString,
                                 $numberString,
                                 $reportString,
                                 $reportmode);

    #
    # receive response from server
    #
    $response = Ermm::CLI::Main::getResponse();

    #
    # Begin loop
    #
    do {
        if ($ermmOutput) {
          #
          # -x option specified; print raw TSLM output
          #
          print $response,"\n";
        }
        else {
          #
          # start normal output processing
          #
          @values = Ermm::CLI::Main::getKeyValueResults($response);

          if ($#values < 0) {
              exit;
          }
          Ermm::CLI::Main::printResults($format, $delimiter, $header, $className,
                                      \@propNames, \@typeNames, \@values);
        }
        $recread += $Ermm::CLI::Conf::objlimit;
        if ($recread >= $records) {
            $flag = "q";
        }

        #
        # Get next part of response
        #
        if (!$flag) {
          Ermm::CLI::Main::nextMMPShowPart();
          #
          # receive response from server
          #
          $response = Ermm::CLI::Main::getResponse();

          #
          # Check if response has values
          #
            if ($response =~ m/text\s*\[.+\]/) {
              if ($Ermm::CLI::Conf::mode) {
                $flag = " ";
              }
              else {
                $flag = "";
              }
            }
            else {
              $flag = "q";
            }

          #
          # Prompt continue or quit
          #
            while ($flag ne "" && $flag ne "q") {
              Ermm::CLI::Main::printtext('CLIMSG_PROMT');
              $flag = <STDIN>;
              chomp $flag;
            }
        }

    }  while (!$flag)
}


1;
